@@ -3,7 +3,7 @@ class HelloWorld:
         self.val = val
 
     def show_hello_world(self):
-        print("Hello World " + str(val))
+        print("Hello World " + str(self.val))
 
 def user_exposed_function(val=0):
     my_hello_world = HelloWorld(val)
